Package: cvTools
Type: Package
Title: Cross-validation tools for regression models
Version: 0.3.2
Date: 2012-05-11
Author: Andreas Alfons
Maintainer: Andreas Alfons <andreas.alfons@econ.kuleuven.be>
Depends: R (>= 2.11.0), lattice, robustbase
Imports: lattice, robustbase, stats
Description: Tools that allow developers to write functions for
        cross-validation with minimal programming effort and assist
        users with model selection.
License: GPL (>= 2)
LazyLoad: yes
Collate: 'accessors.R' 'aggregate.R' 'bwplot.R' 'cost.R' 'cvFit.R'
        'cvFolds.R' 'cvReshape.R' 'cvSelect.R' 'cvTool.R' 'cvTuning.R'
        'densityplot.R' 'dotplot.R' 'plot.R' 'print.R' 'repCV.R'
        'selectBest.R' 'subset.R' 'summary.R' 'utils.R' 'xyplot.R'
Packaged: 2012-05-11 16:02:12 UTC; andi
Repository: CRAN
Date/Publication: 2012-05-14 15:13:43
Built: R 3.4.1; ; 2018-10-13 06:31:45 UTC; windows
