S3method("cvNames<-",cv)
S3method("cvNames<-",cvSelect)
S3method("fits<-",cv)
S3method("fits<-",cvSelect)
S3method(aggregate,cv)
S3method(aggregate,cvSelect)
S3method(aggregate,cvTuning)
S3method(bwplot,cv)
S3method(bwplot,cvSelect)
S3method(cvFit,"function")
S3method(cvFit,call)
S3method(cvFit,default)
S3method(cvNames,cv)
S3method(cvNames,cvSelect)
S3method(cvReshape,cv)
S3method(cvReshape,cvSelect)
S3method(cvTuning,"function")
S3method(cvTuning,call)
S3method(densityplot,cv)
S3method(densityplot,cvSelect)
S3method(dotplot,cv)
S3method(dotplot,cvSelect)
S3method(fits,cv)
S3method(fits,cvSelect)
S3method(ncv,cv)
S3method(ncv,cvSelect)
S3method(nfits,cv)
S3method(nfits,cvSelect)
S3method(plot,cv)
S3method(plot,cvSelect)
S3method(predict,lts)
S3method(print,cv)
S3method(print,cvFolds)
S3method(print,cvSelect)
S3method(print,cvTuning)
S3method(print,summary.cv)
S3method(print,summary.cvSelect)
S3method(print,summary.cvTuning)
S3method(repCV,lm)
S3method(repCV,lmrob)
S3method(repCV,lts)
S3method(subset,cv)
S3method(subset,cvSelect)
S3method(summary,cv)
S3method(summary,cvSelect)
S3method(summary,cvTuning)
S3method(xyplot,cv)
S3method(xyplot,cvSelect)
S3method(xyplot,cvTuning)
export("cvNames<-")
export("fits<-")
export(cvFit)
export(cvFolds)
export(cvLm)
export(cvLmrob)
export(cvLts)
export(cvNames)
export(cvReshape)
export(cvSelect)
export(cvTool)
export(cvTuning)
export(fits)
export(mape)
export(mspe)
export(ncv)
export(nfits)
export(repCV)
export(rmspe)
export(rtmspe)
export(tmspe)
import(lattice)
import(robustbase)
import(stats)
